@@ -1,5 +1,6 @@
 from .. import Handler, Block
 from .options import OPTIONS
+from ..solutions import DjangoSolutions
 
 
 class ContextBlock(Block):
@@ -37,5 +38,24 @@ class ExceptioniteReporter:
         handler.render("terminal")
         handler.request = self.request
         handler.renderer("web").tab("context").add_blocks(ContextBlock)
+        handler.renderer("web").tab("solutions").block("possible_solutions").register(
+            *DjangoSolutions().get()
+        )
         handler.set_options(OPTIONS)
         return handler.render("web")
+
+
+class Exceptionite404Reporter:
+    """Handle Django 404 errors specifically in debug mode."""
+
+    def __init__(self):
+        from mock import patch
+        from django.http import HttpResponseNotFound
+
+        patcher = patch(
+            "django.views.debug.technical_404_response",
+            lambda request, exception: HttpResponseNotFound(
+                ExceptioniteReporter(request, None, exception, None).get_traceback_html()
+            ),
+        )
+        patcher.start()
